@@ -1,14 +1,3 @@
-/*
- * This file is part of hildon-status-menu-widget-example
- *
- * Copyright (C) 2009 Nokia Corporation. All rights reserved.
- *
- * This maemo code example is licensed under a MIT-style license,
- * that can be found in the file called "COPYING" in the root
- * directory.
- *
- */
-
 #ifndef __SSH_STATUS_PLUGIN_H__
 #define __SSH_STATUS_PLUGIN_H__
 
@@ -37,13 +26,13 @@ G_BEGIN_DECLS
 
 typedef struct _SSHStatus        SSHStatus;
 typedef struct _SSHStatusClass   SSHStatusClass;
-typedef struct _SSHStatusPrivate SSHStatusPrivate;
+//typedef struct _SSHStatusPrivate SSHStatusPrivate;
 
 struct _SSHStatus
 {
     HDStatusMenuItem parent;
 
-    SSHStatusPrivate *priv;
+    //SSHStatusPrivate *priv;
 };
 
 struct _SSHStatusClass
